@@ -23,7 +23,7 @@ class Yolo(Base):
         self.options = options
         self.is_locked = False
 
-        self.logger.Debug (4, 'Yolo init params: {}'.format(options))
+        #self.logger.Debug (4, 'Yolo init params: {}'.format(options))
 
         self.processor=self.options.get('object_processor') or 'cpu'
         self.lock_maximum=int(options.get(self.processor+'_max_processes') or 1)
@@ -32,11 +32,12 @@ class Yolo(Base):
         #self.lock_name='pyzm_'+self.processor+'_lock'
         self.lock_name='pyzm_uid{}_{}_lock'.format(os.getuid(),self.processor)
 
-        self.logger.Debug (2,f'portalock: max:{self.lock_maximum}, name:{self.lock_name}, timeout:{self.lock_timeout}')
-        self.lock = portalocker.BoundedSemaphore(maximum=self.lock_maximum, name=self.lock_name,timeout=self.lock_timeout)
+        self.disable_locks = options.get('disable_locks', 'no')
+        if self.disable_locks == 'no':
+            self.logger.Debug (2,f'portalock: max:{self.lock_maximum}, name:{self.lock_name}, timeout:{self.lock_timeout}')
+            self.lock = portalocker.BoundedSemaphore(maximum=self.lock_maximum, name=self.lock_name,timeout=self.lock_timeout)
         self.model_height = self.options.get('model_height', 416)
         self.model_width = self.options.get('model_width', 416)
-        self.disable_locks = options.get('disable_locks', 'no')
 
     def acquire_lock(self):
         if self.disable_locks=='yes':
